@@ -10,7 +10,15 @@ class Modal(hg.DIV):
     SIZES = ["xs", "sm", "md", "lg"]
 
     def __init__(
-        self, heading, *content, label="", size="md", buttons=(), id=None, **attributes
+        self,
+        heading,
+        *content,
+        label="",
+        size="md",
+        buttons=(),
+        id=None,
+        with_form=False,
+        **attributes,
     ):
         """
         heading: Modal title
@@ -36,7 +44,10 @@ class Modal(hg.DIV):
         self.id = hg.html_id(self, prefix="modal-") if id is None else id
         self.openerattributes = {"data_modal_target": hg.format("#{}", self.id)}
         self.contentcontainer = hg.DIV(
-            *content, _class="bx--modal-content", tabindex="0"
+            *content,
+            _class="bx--modal-content"
+            + (" bx--modal-content--with-form" if with_form else ""),
+            tabindex="0",
         )
         super().__init__(
             hg.DIV(
@@ -106,10 +117,12 @@ class Modal(hg.DIV):
             buttons=buttons,
             size="md",
             id=id,
+            with_form=bool(submitlabel),
             **attributes,
         )
         if submitlabel:
             buttons[1].attributes["hx_post"] = url
+            # note: we always use multipart forms, avoids some issues, see ./forms/__init__.py:Form.__init__
             buttons[1].attributes["hx_encoding"] = "multipart/form-data"
             buttons[1].attributes["hx_target"] = hg.format(
                 "#{} .bx--modal-content", modal.id
